"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const validation_1 = __importDefault(require("../exceptions/validation"));
const valueObject_1 = __importDefault(require("../valueObject"));
const invalidUsage_1 = __importDefault(require("../exceptions/invalidUsage"));
const collection_1 = __importDefault(require("./collection"));
class Entity {
    constructor() {
        if (!Entity._isCreating) {
            throw new invalidUsage_1.default();
        }
    }
    static _create(...args) {
        try {
            Entity._isCreating = true;
            const instance = new this(...args);
            instance.validate();
            return instance;
        }
        finally {
            Entity._isCreating = false;
        }
    }
    static _reconstruct(...args) {
        try {
            Entity._isCreating = true;
            return new this(...args);
        }
        finally {
            Entity._isCreating = false;
        }
    }
    static _update(target, ...args) {
        try {
            Entity._isCreating = true;
            const instance = new this(...args);
            instance.validate(target);
            return instance;
        }
        finally {
            Entity._isCreating = false;
        }
    }
    getErrors(prev) {
        return Object.keys(this).reduce((acc, key) => {
            var _a;
            const member = this[key];
            const prevValue = prev ? (_a = prev[key]) !== null && _a !== void 0 ? _a : undefined : undefined;
            if (member && member instanceof collection_1.default) {
                const errors = member.validate(prevValue);
                if (errors) {
                    return Object.entries(errors).reduce((acc, [key, value]) => {
                        var _a;
                        return Object.assign(Object.assign({}, acc), { [key]: [...new Set([...((_a = acc[key]) !== null && _a !== void 0 ? _a : []), ...value])] });
                    }, acc);
                }
            }
            if (member && member instanceof valueObject_1.default) {
                const name = key.replace(/^_/, '');
                const errors = member.validate(name, prevValue);
                if (errors === null || errors === void 0 ? void 0 : errors.length) {
                    return errors.reduce((acc, error) => {
                        var _a;
                        return Object.assign(Object.assign({}, acc), { [error.name]: [...new Set([...((_a = acc[error.name]) !== null && _a !== void 0 ? _a : []), error.error])] });
                    }, acc);
                }
            }
            return acc;
        }, {});
    }
    validate(prev) {
        const errors = this.getErrors(prev);
        if (Object.keys(errors).length) {
            throw new validation_1.default(errors);
        }
    }
}
exports.default = Entity;
Entity._isCreating = false;
//# sourceMappingURL=index.js.map