"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TestEntity = exports.TestText = void 0;
const text_1 = __importDefault(require("../valueObject/text"));
const _1 = __importDefault(require("."));
const jest_circus_1 = require("jest-circus");
class TestText extends text_1.default {
    get symbol() {
        return Symbol();
    }
    getValidationMaxLength() {
        return 5;
    }
}
exports.TestText = TestText;
class TestEntity extends _1.default {
    /**
     * @deprecated create or reconstruct 経由で生成
     */
    constructor(text1, text2, text3, text4) {
        super();
        this.text1 = text1;
        this.text2 = text2;
        this.text3 = text3;
        this.text4 = text4;
    }
    static create(text1, text2) {
        return TestEntity._create(text1, text2);
    }
    static reconstruct(text1, text2, text3, text4) {
        return TestEntity._reconstruct(text1, text2, text3, text4);
    }
    update({ text3, text4 }) {
        return TestEntity._update(this, this.text1, this.text2, text3, text4);
    }
    equals(other) {
        return this.text1.equals(other.text1);
    }
}
exports.TestEntity = TestEntity;
(0, jest_circus_1.describe)('Entity', () => {
    it('should throw error if call constructor directory', () => {
        expect(() => new TestEntity(TestText.create(1), TestText.create(2), TestText.create(3), TestText.create(4))).toThrow();
    });
    (0, jest_circus_1.describe)('equals', () => {
        it('should return true', () => {
            expect(TestEntity.reconstruct(TestText.create(1), TestText.create(2), TestText.create(3), TestText.create(4)).equals(TestEntity.reconstruct(TestText.create(1), TestText.create(2), TestText.create(3), TestText.create(4)))).toBe(true);
            expect(TestEntity.reconstruct(TestText.create(1), TestText.create(2), TestText.create(3), TestText.create(4)).equals(TestEntity.reconstruct(TestText.create(1), TestText.create(0), TestText.create(0), TestText.create(0)))).toBe(true);
        });
        it('should return false', () => {
            expect(TestEntity.reconstruct(TestText.create(1), TestText.create(2), TestText.create(3), TestText.create(4)).equals(TestEntity.reconstruct(TestText.create(0), TestText.create(2), TestText.create(3), TestText.create(4)))).toBe(false);
        });
    });
    (0, jest_circus_1.describe)('create', () => {
        it('should not throw error', () => {
            expect(() => TestEntity.create(TestText.create(1), TestText.create('1'))).not.toThrow();
        });
        it('should throw error', () => {
            let error;
            try {
                TestEntity.create(TestText.create(1), TestText.create(''));
            }
            catch (e) {
                error = e;
            }
            expect(error).not.toBeUndefined();
            expect(error === null || error === void 0 ? void 0 : error.message).toBe('バリデーションエラーが発生しました');
            expect(error === null || error === void 0 ? void 0 : error.errors).toEqual({
                text2: ['値を指定してください'],
            });
        });
    });
    (0, jest_circus_1.describe)('reconstruct', () => {
        it('should not throw error', () => {
            expect(() => TestEntity.reconstruct(TestText.create(1), TestText.create(''), TestText.create(1), TestText.create('abcdef'))).not.toThrow();
        });
    });
    (0, jest_circus_1.describe)('update', () => {
        it('should not throw error', () => {
            var _a, _b;
            const test = TestEntity.create(TestText.create(1), TestText.create('1')).update({
                text3: TestText.create(1),
                text4: TestText.create('abcde'),
            });
            expect((_a = test.text3) === null || _a === void 0 ? void 0 : _a.value).toBe('1');
            expect((_b = test.text4) === null || _b === void 0 ? void 0 : _b.value).toBe('abcde');
        });
        it('should throw error', () => {
            const test = TestEntity.create(TestText.create(1), TestText.create('1'));
            let error;
            try {
                test.update({
                    text3: TestText.create(1),
                    text4: TestText.create('abcdef'),
                });
            }
            catch (e) {
                error = e;
            }
            expect(error).not.toBeUndefined();
            expect(error === null || error === void 0 ? void 0 : error.message).toBe('バリデーションエラーが発生しました');
            expect(error === null || error === void 0 ? void 0 : error.errors).toEqual({
                text4: ['5文字より短く入力してください'],
            });
        });
    });
});
//# sourceMappingURL=index.spec.js.map